ownerOf static method

Images? ownerOf(
  1. Image image
)

Returns the cache that image was loaded into, or null if the image does not belong to any cache.

Only the image object that the cache handed out is recognized, a clone of it is not.

Implementation

static Images? ownerOf(Image image) {
  final asset = _assetsByImage[image];
  if (asset == null || !asset.owner._isLive(asset)) {
    return null;
  }
  return asset.owner;
}