retainCount method

int retainCount(
  1. String key
)

The number of times that the image under key is currently retained.

Returns 0 when there is no such image in the cache.

Implementation

int retainCount(String key) => _assets[key]?.refCount ?? 0;