sizeBytesOf method

int sizeBytesOf(
  1. String key
)

The estimated size, in bytes, of the image under key.

Returns 0 when there is no such image in the cache or when it is still loading.

Implementation

int sizeBytesOf(String key) => _assets[key]?.sizeBytes ?? 0;