CollisionProspect<T> class abstract

A CollisionProspect is an immutable view of a pair of two potentially colliding hitboxes.

Equality is based on unordered pair identity: {A, B} == {B, A}.

Annotations

Constructors

CollisionProspect()

Properties

a → T
no setter
b → T
no setter
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override