reset method
void
reset()
Resets the pool for the next frame. Previously acquired prospects should not be accessed after this call.
Implementation
void reset() {
_count = 0;
}
Resets the pool for the next frame. Previously acquired prospects should not be accessed after this call.
void reset() {
_count = 0;
}