intersections method
Check what the intersection points of two collidables are, returns an empty list if there are no intersections.
Implementation
@override
List<Vector2> intersections(
ShapeHitbox hitboxA,
ShapeHitbox hitboxB,
) {
return hitboxA.intersections(hitboxB);
}