opposite property
Anchor
get
opposite
Returns the anchor on the opposite side of this anchor.
Implementation
Anchor get opposite => Anchor(1 - x, 1 - y);
Returns the anchor on the opposite side of this anchor.
Anchor get opposite => Anchor(1 - x, 1 - y);