onHotReload method
Called when Flutter's hot reload is triggered.
Override this method to reload assets, recalculate cached values, or perform other actions in response to hot reload.
This is only called in debug mode.
Implementation
@mustCallSuper
void onHotReload() => handleHotReload();