isRegistered<C extends Component> method
Whether type C has been registered as a queryable type.
Implementation
bool isRegistered<C extends Component>() {
return _queries?.containsKey(C) ?? false;
}
Whether type C has been registered as a queryable type.
bool isRegistered<C extends Component>() {
return _queries?.containsKey(C) ?? false;
}