clear method

void clear()

Clears all available components from the pool. This can be useful if you want to free up memory or reset the pool state.

Note: This does not affect components that are currently in use.

Implementation

void clear() {
  _available.clear();
}