removeOnFinish property
If the component should be removed once the animation has finished.
Needs the animation to have loop = false to ever remove the component,
since it will never finish otherwise.
If the component should be removed once the animation has finished.
Needs the animation to have loop = false to ever remove the component,
since it will never finish otherwise.