timePerChar property
Defaults to 0. If not zero, the characters will appear one-by-one giving a typing effect to the text box, and this will be the delay in seconds between each character.
Defaults to 0. If not zero, the characters will appear one-by-one giving a typing effect to the text box, and this will be the delay in seconds between each character.