isPainted property
bool
get
isPainted
Whether the widget was painted during the last game render pass.
This is false while the component is not rendered, for example because an ancestor is hidden, in which case the hosted widget is also excluded from focus and semantics.
Implementation
bool get isPainted => _isPainted;