events library

Classes

Dispatcher<G extends FlameGame<World>>
DisplacementEvent<R>
Base class for events that contain two points on the screen, representing some sort of movement (from a "start" to and "end") and having a "delta". These include: drag events and (in the future) pointer move events.
DoubleTapCancelEvent
DoubleTapDispatcher
DoubleTapDispatcher propagates double-tap events to every components in the component tree that is mixed with DoubleTapCallbacks. This will be attached to the FlameGame instance automatically whenever any DoubleTapCallbacks are mounted into the component tree.
DoubleTapDispatcherKey
DoubleTapDownEvent
DoubleTapEvent
DragCancelEvent
DragDownInfo
DragEndEvent
DragEndInfo
DragStartEvent
The event propagated through the Flame engine when the user starts a drag gesture on the game canvas.
DragStartInfo
DragUpdateEvent
DragUpdateInfo
Event<R>
Base class for a variety of input events, such as tap events, drag events, keyboard events, etc.
ForcePressInfo
HardwareKeyboardDetector
The HardwareKeyboardDetector component allows you to directly listen to events from a hardware keyboard, bypassing the Focus widget in Flutter. It will not listen for events from any on-screen (software) keyboards.
LocationContextEvent<C, R>
A base event that includes a location context, i.e. a position or set of positions in which the event happens.
LongPressCancelEvent
The event propagated through the Flame engine when a long press gesture is cancelled before completing.
LongPressDispatcher
A component that dispatches long-press gesture events to components that use the LongPressCallbacks mixin. It will be attached to the FlameGame instance automatically whenever any LongPressCallbacks components are mounted into the component tree.
LongPressDispatcherKey
Unique key for the LongPressDispatcher so the game can identify it.
LongPressEndEvent
The event propagated through the Flame engine when a long press gesture ends (the user lifts their pointer after a long press).
LongPressEndInfo
LongPressMoveUpdateEvent
The event propagated through the Flame engine when the user moves their pointer during an active long press gesture.
LongPressMoveUpdateInfo
LongPressStartEvent
The event propagated through the Flame engine when the user completes a long press gesture (i.e. the pointer has been held down long enough to be recognized as a long press).
LongPressStartInfo
MouseMoveDispatcherKey
MultiDragListener
Interface that must be implemented by a game in order for it to be eligible to receive events from an ImmediateMultiDragGestureRecognizer.
MultiDragScaleDispatcher
Dispatches both drag and scale events to DragCallbacks and ScaleCallbacks components. Attached to the FlameGame automatically when either callback type is first mounted.
MultiDragScaleDispatcherKey
MultiDragScaleGestureRecognizer
A gesture recognizer that can recognize both individual pointer drags and scale gestures simultaneously.
MultiTapDispatcher
MultiTapDispatcherKey
MultiTapListener
Interface that must be implemented by a game in order for it to be eligible to receive events from a MultiTapGestureRecognizer.
NonPrimaryTapDispatcher
NonPrimaryTapDispatcher propagates non-primary tap events (i.e. secondary/right and tertiary/middle mouse clicks) to every component in the component tree that is mixed with SecondaryTapCallbacks or TertiaryTapCallbacks. This will be attached to the FlameGame instance automatically whenever any of those callbacks are mounted into the component tree.
NonPrimaryTapDispatcherKey
PointerHoverInfo
PointerMoveDispatcher
MouseMoveDispatcher facilitates dispatching of mouse move events to the PointerMoveCallbacks components in the component tree. It will be attached to the FlameGame instance automatically whenever any PointerMoveCallbacks components are mounted into the component tree.
PointerMoveEvent
PointerScrollInfo
PositionEvent<R>
Base class for events that originate at some point on the screen. These include: tap events, scale events, etc.
PositionInfo<T>
A more specialized wrapper of Flame's base class for input events. It adds the eventPosition field and is used by all position based events on Flame.
ScaleEndEvent
Event propagated through the Flame engine when a scale gesture ends.
ScaleEndInfo
ScaleListener
Interface that must be implemented by a game in order for it to be eligible to receive events from an ScaleGestureRecognizer.
ScaleStartEvent
The event propagated through the Flame engine when the user starts a scale (pinch/zoom) gesture on the game canvas.
ScaleStartInfo
ScaleUpdateEvent
Event propagated through the Flame engine when the user updates a scale (pinch/zoom/rotate) gesture on the game canvas.
ScaleUpdateInfo
ScrollDispatcher
ScrollDispatcher facilitates dispatching of pointer scroll events to the ScrollCallbacks components in the component tree. It will be attached to the FlameGame instance automatically whenever any ScrollCallbacks components are mounted into the component tree.
ScrollDispatcherKey
Unique key for the ScrollDispatcher so the game can identify it.
ScrollEvent
Event fired when a pointer scroll (mouse wheel) occurs.
SecondaryTapCancelEvent
The event propagated through the Flame engine when a secondary tap (i.e. right mouse button click) on a component is cancelled.
SecondaryTapDownEvent
The event propagated through the Flame engine when the user starts a secondary touch (i.e. right mouse click) on the game canvas.
SecondaryTapUpEvent
The event propagated through the Flame engine when the user stops secondary touching (i.e. right mouse button) the game canvas.
TapCancelEvent
The event propagated through the Flame engine when a tap on a component is cancelled.
TapDownEvent
The event propagated through the Flame engine when the user starts a touch on the game canvas.
TapDownInfo
TapUpEvent
The event propagated through the Flame engine when the user stops touching the game canvas.
TapUpInfo
TertiaryTapCancelEvent
The event propagated through the Flame engine when a tertiary tap (i.e. middle mouse button click) on a component is cancelled.
TertiaryTapDownEvent
The event propagated through the Flame engine when the user starts a tertiary touch (i.e. middle mouse click) on the game canvas.
TertiaryTapUpEvent
The event propagated through the Flame engine when the user stops tertiary touching (i.e. middle mouse button) the game canvas.

Mixins

DoubleTapCallbacks
DoubleTapCallbacks adds the ability to receive double-tap events in a component.
DoubleTapDetector
DragCallbacks
This mixin can be added to a Component allowing it to receive drag events.
ForcePressDetector
HasKeyboardHandlerComponents<W extends World>
A FlameGame mixin that implements KeyboardEvents with keyboard event propagation to components that are mixed with KeyboardHandler.
HorizontalDragDetector
HoverCallbacks
This mixin can be added to a Component allowing it to receive hover events.
KeyboardEvents
A Game mixin to make a game subclass sensitive to keyboard events.
LongPressCallbacks
This mixin can be added to a Component allowing it to receive long-press events.
LongPressDetector
MouseMovementDetector
MultiTouchDragDetector
Mixin that can be added to a Game allowing it to receive drag events.
MultiTouchTapDetector
Mixin that can be added to a Game allowing it to receive tap events.
PanDetector
PointerMoveCallbacks
This mixin can be added to a Component allowing it to receive pointer movement events.
ScaleCallbacks
Mixin for components that respond to scale (pinch/zoom/rotate) gestures.
ScaleDetector
ScrollCallbacks
This mixin can be added to a Component allowing it to receive pointer scroll (mouse wheel) events.
ScrollDetector
SecondaryTapCallbacks
This mixin can be added to a Component allowing it to receive secondary tap events (i.e. right mouse clicks).
SecondaryTapDetector
TapCallbacks
This mixin can be added to a Component allowing it to receive tap events.
TertiaryTapCallbacks
This mixin can be added to a Component allowing it to receive tertiary tap events (i.e. middle mouse clicks).
TertiaryTapDetector
VerticalDragDetector