Event<R> class abstract

Base class for a variety of input events, such as tap events, drag events, keyboard events, etc.

This base class offers only simple common functionality; please see the concrete Event subclasses for the information about each individual event and the circumstances when they occur.

The type parameter R represents the type of the original Flutter raw event that triggered this Flame event.

Implementers

Constructors

Event({required R raw})

Properties

continuePropagation bool
If this flag is false (default), the event will be delivered to the first component that can handle it. If that component sets this flag to true, the event will propagate further down the component tree to other eligible components.
getter/setter pair
handled bool
Flag that can be used to indicate that the event was handled by one of the components.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
raw ↔ R
The original Flutter raw event that triggered this Flame event.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited