LocationContextEvent<C, R> class abstract

A base event that includes a location context, i.e. a position or set of positions in which the event happens.

The type parameter C is the generalization of the representation used to describe the location instance, such as a Vector2.

Inheritance
Implementers

Constructors

LocationContextEvent({required R raw})

Properties

continuePropagation bool
If this flag is false (default), the event will be delivered to the first component that can handle it. If that component sets this flag to true, the event will propagate further down the component tree to other eligible components.
getter/setter pairinherited
handled bool
Flag that can be used to indicate that the event was handled by one of the components.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
parentContext → C?
The context in the parent's coordinate space, containing start and end points.
no setter
raw ↔ R
The original Flutter raw event that triggered this Flame event.
getter/setter pairinherited
renderingTrace List<C>
The stacktrace of coordinates of the event within the components in their rendering order.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited