parentContext property
C?
get
parentContext
The context in the parent's coordinate space, containing start and end points.
Null when the receiving component is the root of the delivery.
Like the local coordinates, this is only accessible while the event is
being propagated to the components via deliverAtPoint, and is null at
other times.
Implementation
C? get parentContext {
if (renderingTrace.length >= 2) {
final lastIndex = renderingTrace.length - 1;
return renderingTrace[lastIndex - 1];
} else {
return null;
}
}