isLongPressing property
bool
get
isLongPressing
Returns true while a long press gesture is active on this component.
Implementation
bool get isLongPressing => _isLongPressing;
Returns true while a long press gesture is active on this component.
bool get isLongPressing => _isLongPressing;