LongPressCancelEvent class
The event propagated through the Flame engine when a long press gesture is cancelled before completing.
This may happen if the pointer moves too far before the long press duration elapses, or if the gesture is otherwise interrupted.
Constructors
- LongPressCancelEvent(int pointerId)
Properties
- continuePropagation ↔ bool
-
If this flag is false (default), the event will be delivered to the first
component that can handle it. If that component sets this flag to true,
the event will propagate further down the component tree to other eligible
components.
getter/setter pairinherited
- handled ↔ bool
-
Flag that can be used to indicate that the event was handled by one of the
components.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- pointerId → int
-
The id of the gesture that was cancelled.
final
- raw ↔ void
-
The original Flutter raw event that triggered this Flame event.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited