LongPressEndEvent class
The event propagated through the Flame engine when a long press gesture ends (the user lifts their pointer after a long press).
This is a PositionEvent, where the position is the point where the pointer was lifted.
- Inheritance
-
- Object
- Event<
LongPressEndDetails> - LocationContextEvent<
Vector2, LongPressEndDetails> - PositionEvent<
LongPressEndDetails> - LongPressEndEvent
Constructors
- LongPressEndEvent(int pointerId, Game game, LongPressEndDetails details)
Properties
- canvasPosition → Vector2
-
Event position in the coordinate space of the game widget, i.e. relative
to the game canvas.
latefinalinherited
- continuePropagation ↔ bool
-
If this flag is false (default), the event will be delivered to the first
component that can handle it. If that component sets this flag to true,
the event will propagate further down the component tree to other eligible
components.
getter/setter pairinherited
- devicePosition → Vector2
-
Event position in the coordinate space of the device -- either the phone,
or the browser window, or the app.
finalinherited
- handled ↔ bool
-
Flag that can be used to indicate that the event was handled by one of the
components.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- localPosition → Vector2
-
Event position in the local coordinate space of the current component.
no setterinherited
- parentContext → Vector2?
-
The context in the parent's coordinate space, containing start and end
points.
no setterinherited
- pointerId → int
-
The unique identifier for this long press gesture.
final
- raw ↔ LongPressEndDetails
-
The original Flutter raw event that triggered this Flame event.
getter/setter pairinherited
-
renderingTrace
→ List<
Vector2> -
The stacktrace of coordinates of the event within the components in their
rendering order.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- velocity → Vector2
-
The velocity of the pointer at the time the long press ended.
final
Methods
-
collectApplicableChildren(
{required Component rootComponent}) → Iterable< Component> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited