LongPressMoveUpdateEvent class

The event propagated through the Flame engine when the user moves their pointer during an active long press gesture.

This is a DisplacementEvent whose start/end positions represent a frame-to-frame delta, matching the semantics of DragUpdateEvent. Use localDelta to move a component to follow the pointer.

Inheritance

Constructors

LongPressMoveUpdateEvent(int pointerId, Game game, LongPressMoveUpdateDetails details, {required Offset previousGlobalPosition})
Creates a LongPressMoveUpdateEvent.

Properties

canvasDelta Vector2
Event delta in the coordinate space of the game widget, i.e. relative to the game canvas.
latefinalinherited
canvasEndPosition Vector2
Event end position in the coordinate space of the game widget, i.e. relative to the game canvas.
latefinalinherited
canvasStartPosition Vector2
Event start position in the coordinate space of the game widget, i.e. relative to the game canvas.
latefinalinherited
continuePropagation bool
If this flag is false (default), the event will be delivered to the first component that can handle it. If that component sets this flag to true, the event will propagate further down the component tree to other eligible components.
getter/setter pairinherited
deviceDelta Vector2
Event delta in the coordinate space of the device -- either the phone, or the browser window, or the app.
latefinalinherited
deviceEndPosition Vector2
Event end position in the coordinate space of the device -- either the phone, or the browser window, or the app.
finalinherited
deviceStartPosition Vector2
Event start position in the coordinate space of the device -- either the phone, or the browser window, or the app.
finalinherited
handled bool
Flag that can be used to indicate that the event was handled by one of the components.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
localDelta Vector2
Event delta in the local coordinate space of the current component.
no setterinherited
localEndPosition Vector2
Event end position in the local coordinate space of the current component.
no setterinherited
localStartPosition Vector2
Event start position in the local coordinate space of the current component.
no setterinherited
offsetFromOrigin Vector2
The offset from the initial long press contact point.
final
parentContext → DisplacementContext?
The context in the parent's coordinate space, containing start and end points.
no setterinherited
pointerId int
The unique identifier for this long press gesture.
final
raw LongPressMoveUpdateDetails
The original Flutter raw event that triggered this Flame event.
getter/setter pairinherited
renderingTrace List<DisplacementContext>
The stacktrace of coordinates of the event within the components in their rendering order.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

collectApplicableChildren({required Component rootComponent}) Iterable<Component>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited