pointerId property
The unique identifier for this long press gesture.
Subsequent move update, end, or cancel events will carry the same pointer id.
Implementation
final int pointerId;
The unique identifier for this long press gesture.
Subsequent move update, end, or cancel events will carry the same pointer id.
final int pointerId;