onStart property
Called when a pointer starts dragging. One callback per pointer. Return a Drag object to receive updates for this specific pointer.
Implementation
GestureMultiDragStartCallback? onStart;
Called when a pointer starts dragging. One callback per pointer. Return a Drag object to receive updates for this specific pointer.
GestureMultiDragStartCallback? onStart;