scaleThreshold property
The threshold for determining when a scale gesture has occurred. Default is 1.05 (5% change in scale).
Implementation
final double scaleThreshold;
The threshold for determining when a scale gesture has occurred. Default is 1.05 (5% change in scale).
final double scaleThreshold;