PositionEvent<R> class abstract

Base class for events that originate at some point on the screen. These include: tap events, scale events, etc.

This class includes properties that describe the position where the event has occurred.

Inheritance
Implementers

Constructors

PositionEvent(Game _game, {required Vector2 devicePosition, required R raw})

Properties

canvasPosition Vector2
Event position in the coordinate space of the game widget, i.e. relative to the game canvas.
latefinal
continuePropagation bool
If this flag is false (default), the event will be delivered to the first component that can handle it. If that component sets this flag to true, the event will propagate further down the component tree to other eligible components.
getter/setter pairinherited
devicePosition Vector2
Event position in the coordinate space of the device -- either the phone, or the browser window, or the app.
final
handled bool
Flag that can be used to indicate that the event was handled by one of the components.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
localPosition Vector2
Event position in the local coordinate space of the current component.
no setter
parentContext Vector2?
The context in the parent's coordinate space, containing start and end points.
no setterinherited
raw ↔ R
The original Flutter raw event that triggered this Flame event.
getter/setter pairinherited
renderingTrace List<Vector2>
The stacktrace of coordinates of the event within the components in their rendering order.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

collectApplicableChildren({required Component rootComponent}) Iterable<Component>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited