ScaleListener class abstract

Interface that must be implemented by a game in order for it to be eligible to receive events from an ScaleGestureRecognizer.

Instead of implementing this class directly consider using one of the prebuilt mixins:

Implementers

Constructors

ScaleListener()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handleScaleEnd(ScaleEndDetails details) → void
Marks the end of a drag operation.
handleScaleStart(ScaleStartDetails details) → void
The beginning of a drag operation.
handleScaleUpdate(ScaleUpdateDetails details) → void
The pointer that was touching the screen has moved.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited