handleScaleEnd abstract method

void handleScaleEnd(
  1. ScaleEndDetails details
)

Marks the end of a drag operation.

This event fires when the pointer stops touching the screen. It will fire even if the pointer is currently outside of the game widget.

Implementation

void handleScaleEnd(ScaleEndDetails details);