handleScaleStart abstract method

void handleScaleStart(
  1. ScaleStartDetails details
)

The beginning of a drag operation.

If the game is not listening to tap events, this event will occur as soon as the user touches the screen. If the game uses both a MultiTapListener and a MultiDragListener simultaneously, then this event will fire once the user moves their finger away from the point of the initial touch.

Implementation

void handleScaleStart(ScaleStartDetails details);