scrollDelta property
The scroll delta in logical pixels.
Positive values indicate scrolling down or to the right, negative values indicate scrolling up or to the left.
Implementation
final Vector2 scrollDelta;
The scroll delta in logical pixels.
Positive values indicate scrolling down or to the right, negative values indicate scrolling up or to the left.
final Vector2 scrollDelta;