PathExtension extension
- on
Properties
- centered → Path
-
Available on Path, provided by the PathExtension extension
Returns a new Path translated such that itscenteris at zero.no setter -
contours
→ List<
PathMetric> -
Available on Path, provided by the PathExtension extension
Return a list of PathMetric objects, corresponding to the contours in this path.no setter - toOrigin → Path
-
Available on Path, provided by the PathExtension extension
Returns a new Path translated such that itstopLeftis at zero.no setter
Methods
-
resizeTo(
Size size, {bool keepRatio = false}) → Path -
Available on Path, provided by the PathExtension extension
Returns a new Path with the givensize. IfkeepRatiois true the aspect ratio is kept, so that the path fits within thesize. -
transform32(
Float32List matrix4) → Path -
Available on Path, provided by the PathExtension extension
-
walkContourAt(
int index, [double sampling = 1.0, double? tolerance]) → List< Offset> -
Available on Path, provided by the PathExtension extension
Walk only the contour atindex, without sampling the other contours of the path. -
walkContours(
[double sampling = 1.0, double? tolerance]) → List< List< Offset> > -
Available on Path, provided by the PathExtension extension
Walk the contours of a Path and return them as a list of Offset lists. Each entry in the list corresponds to a given sub-contour.