walkContours method
Walk the contours of a Path and return them as a list of Offset lists. Each entry in the list corresponds to a given sub-contour.
See PathMetricExtension.walkContour for the sampling and the
tolerance parameters.
Implementation
List<List<Offset>> walkContours([
double sampling = 1.0,
double? tolerance,
]) {
return [
for (final metric in computeMetrics())
metric.walkContour(sampling, tolerance),
];
}