onHotReload method
void
onHotReload()
Called when Flutter's hot reload is triggered.
FlameGame overrides this to propagate the notification to all components in the component tree.
Implementation
void onHotReload() {}
Called when Flutter's hot reload is triggered.
FlameGame overrides this to propagate the notification to all components in the component tree.
void onHotReload() {}