loadingBuilder property

WidgetBuilder? loadingBuilder
final

Builder to provide a widget which will be displayed while the game is loading. By default this is an empty Container.

For a FlameGame, the game counts as loading until the whole initial component tree has been loaded and mounted, so the game does not start until every component added during Game.onLoad is ready.

Implementation

final GameLoadingWidgetBuilder? loadingBuilder;