GameWidgetState<T extends Game> class

Inheritance

Constructors

GameWidgetState()

Properties

context → BuildContext
The location in the tree where this widget builds.
no setterinherited
currentGame ↔ T
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
loaderFuture → Future<void>
no setter
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widget → GameWidget<T>
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant GameWidget<T> oldWidget) → void
Called whenever the widget configuration changes.
override
dispose() → void
Called when this object is removed from the tree permanently.
override
disposeCurrentGame({bool callGameOnDispose = false}) → void
disposeCurrentGame is called by two flutter events - didUpdateWidget and dispose. When the parameter callGameOnDispose is true, the currentGame's onDispose method will be called; otherwise, it will not.
initCurrentGame() → void
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
override
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

initGameStateListener(Game currentGame, void onGameStateChange()) → void
Visible for testing for https://github.com/flame-engine/flame/issues/2771.