PathPathIntersections class
- Inheritance
-
- Object
- Intersections<
PathComponent, PathComponent> - PathPathIntersections
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
intersect(
PathComponent pathA, PathComponent pathB, {Rect? overlappingRect}) → List< Vector2> -
Returns the intersection points of the edges of all the polygons of
pathAandpathB.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
supportsShapes(
ShapeComponent shapeA, ShapeComponent shapeB) → bool -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
unorderedIntersect(
ShapeComponent shapeA, ShapeComponent shapeB, {Rect? overlappingRect}) → List< Vector2> -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited