PaletteEntry class

Constructors

PaletteEntry(Color color)
const

Properties

color → Color
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

brighten(double amount) → PaletteEntry
darken(double amount) → PaletteEntry
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint() → Paint
toString() → String
A string representation of this object.
inherited
withAlpha(int alpha) → PaletteEntry
withBlue(int blue) → PaletteEntry
withGreen(int green) → PaletteEntry
withRed(int red) → PaletteEntry

Operators

operator ==(Object other) → bool
The equality operator.
inherited