ParallaxRenderer class abstract

Implementers

Constructors

ParallaxRenderer({ImageRepeat? repeat, Alignment? alignment, LayerFill? fill, FilterQuality? filterQuality})

Properties

alignment → Alignment
How to align the image in relation to the screen
final
fill → LayerFill
How to fill the screen with the image, always proportionally scaled.
final
filterQuality → FilterQuality
final
hashCode → int
The hash code for this object.
no setterinherited
image → Image
no setter
repeat → ImageRepeat
If and how the image should be repeated on the canvas
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update(double dt) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited