alignment property
How to align the image in relation to the screen
Implementation
final Alignment alignment = alignment ?? Alignment.bottomLeft;
How to align the image in relation to the screen
final Alignment alignment = alignment ?? Alignment.bottomLeft;