fill property
How to fill the screen with the image, always proportionally scaled.
Implementation
final LayerFill fill = fill ?? LayerFill.height;
How to fill the screen with the image, always proportionally scaled.
final LayerFill fill = fill ?? LayerFill.height;