renderCallback property
Called every frame with the canvas, already transformed to the emitter component's local coordinate system, and the live particles.
Implementation
final void Function(Canvas canvas, ParticleBuffer particles) renderCallback;
Called every frame with the canvas, already transformed to the emitter component's local coordinate system, and the live particles.
final void Function(Canvas canvas, ParticleBuffer particles) renderCallback;