CircleParticle class

Plain circle with no other behaviors.

Consider composing this with other Particles to achieve needed effects.

Inheritance

Constructors

CircleParticle({required Paint paint, double radius = 10.0, double? lifespan})

Properties

hashCode → int
The hash code for this object.
no setterinherited
lifespan → double
Getter for the current lifespan of this Particle.
no setterinherited
paint → Paint
final
progress → double
Getter which should be used by subclasses to get overall progress.
no setterinherited
radius → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shouldRemove → bool
This method will return true as soon as the particle reaches the end of its lifespan.
no setterinherited

Methods

accelerated({required Vector2 acceleration, Vector2? position, Vector2? speed}) → Particle
Wraps this particle with a AcceleratedParticle.
inherited
moving({required Vector2 to, Vector2? from, Curve curve = Curves.linear}) → Particle
Wraps this particle with a MovingParticle.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Canvas canvas) → void
Should render this Particle to given Canvas.
override
rotated(double angle) → Particle
Rotates this particle to a fixed angle in radians using the RotatingParticle.
inherited
rotating({double from = 0, double to = pi}) → Particle
Rotates this particle from a given angle to another one in radians using RotatingParticle.
inherited
scaled(double scale) → Particle
Wraps this particle with a ScaledParticle.
inherited
scaling({double to = 0, Curve curve = Curves.linear}) → ScalingParticle
Wraps this particle with a ScalingParticle.
inherited
setLifespan(double lifespan) → void
A control method allowing a parent of this Particle to pass down it's lifespan.
inherited
toString() → String
A string representation of this object.
inherited
translated(Vector2 offset) → Particle
Wraps this particle with a TranslatedParticle.
inherited
update(double dt) → void
Updates the _timer of this Particle.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited