ColorRamp.solid constructor
ColorRamp.solid(
- Color color
A ramp that keeps the same color over the whole lifetime.
Implementation
ColorRamp.solid(Color color) : this([color]);
A ramp that keeps the same color over the whole lifetime.
ColorRamp.solid(Color color) : this([color]);