EmitterBurst class
A one-off release of count particles, time seconds after emission
starts.
Constructors
-
EmitterBurst(double time, int count)
-
Releases
count particles time seconds after emission starts.
const
Properties
-
count
→ int
-
The number of particles released by the burst.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
time
→ double
-
Seconds after emission start at which the burst fires.
final
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited