RectangleEmitterShape class

Spawns particles uniformly inside a rectangle centered on the emitter.

Inheritance

Constructors

RectangleEmitterShape(double width, double height)
Spawns particles inside a centered rectangle of width by height.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → double
The height of the spawn rectangle, in local units.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
The width of the spawn rectangle, in local units.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
samplePosition(Random random, Vector2 out) → void
Writes a spawn offset, relative to the emitter, into out.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited