BatchItem class

A single item in a SpriteBatch.

Holds all the important information of a batch item.

Constructors

BatchItem({required Rect source, required RSTransform transform, Color? color, bool flip = false, double bleed = 0})

Properties

bleed double
The bleed value for this batch item in pixels.
getter/setter pair
color Color
The color of the batch item (used for building the drawAtlas color list).
getter/setter pair
destination Rect
The destination rectangle for the Canvas, used in the non-atlas rendering path.
getter/setter pair
flip bool
The flip value for this batch item.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
matrix Matrix4
no setter
paint Paint
Paint object used for the web.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source Rect
The source rectangle on the SpriteBatch.atlas.
getter/setter pair
transform RSTransform
The transform values for this batch item.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited