destination property

Rect destination
getter/setter pair

The destination rectangle for the Canvas, used in the non-atlas rendering path.

It will be transformed by matrix. When bleed is greater than zero, this rect extends bleed pixels in each direction beyond the source size to prevent edge artifacts in the non-atlas rendering path.

Implementation

Rect destination;