dispose method
Releases any native resources held by this element.
The element must not be drawn after this has been called. Elements that hold no such resources do nothing.
Implementation
@override
void dispose() {
_textPainter.dispose();
}
Releases any native resources held by this element.
The element must not be drawn after this has been called. Elements that hold no such resources do nothing.
@override
void dispose() {
_textPainter.dispose();
}