StrikethroughTextNode class

An InlineTextNode representing a text with a strikethrough line.

The exact styling can be controlled by the strikethroughText property on the document style.

Inheritance

Properties

child → InlineTextNode
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style ↔ InlineTextStyle
getter/setter pairinherited

Methods

fillStyles(DocumentStyle stylesheet, InlineTextStyle parentTextStyle) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toInlineSpan() → InlineSpan
Converts this node into a Flutter InlineSpan carrying its resolved style, so that a whole block of inline nodes can be laid out by Flutter's paragraph engine.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

defaultStyle → InlineTextStyle
final