NineTileBoxWidget class

A StatelessWidget that renders NineTileBox

Inheritance

Constructors

NineTileBoxWidget({required Image image, required double tileSize, required double destTileSize, double? width, double? height, Widget? child, EdgeInsetsGeometry? padding, Key? key})
const
NineTileBoxWidget.asset({required String path, required double tileSize, required double destTileSize, Images? images, double? width, double? height, Widget? child, EdgeInsetsGeometry? padding, WidgetBuilder? errorBuilder, WidgetBuilder? loadingBuilder, Key? key})
Loads image from the asset path and renders it as a widget.

Properties

child → Widget?
final
destTileSize → double
The size of the tile that will be used to render on the canvas
final
errorBuilder → WidgetBuilder?
A builder function that is called if the loading fails
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingBuilder → WidgetBuilder?
A builder function that is called while the loading is on the way
final
padding → EdgeInsetsGeometry?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tileSize → double
The size of the tile on the image
final
width → double?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<NineTileBoxWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited