CollisionProspect<T> class
abstract
A CollisionProspect is an immutable view of a pair of two potentially colliding hitboxes.
Equality is based on unordered pair identity: {A, B} == {B, A}.
- Annotations
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override