availableCount property
int
get
availableCount
The number of components currently available in the pool for acquisition.
This does not include components that are currently in use (i.e., those that have been acquired but not yet returned to the pool). It only counts the components that are ready to be acquired.
Implementation
int get availableCount => _available.length;