maxSize property
The maximum number of components that can be stored in the pool. If the pool reaches this limit, additional components released back to the pool will be discarded.
Implementation
final int maxSize;
The maximum number of components that can be stored in the pool. If the pool reaches this limit, additional components released back to the pool will be discarded.
final int maxSize;