Base class for events that contain two points on the screen, representing
some sort of movement (from a "start" to and "end") and having a "delta".
These include: drag events and (in the future) pointer move events.
DoubleTapDispatcher propagates double-tap events to every components in
the component tree that is mixed with DoubleTapCallbacks. This will be
attached to the FlameGame instance automatically whenever any
DoubleTapCallbacks are mounted into the component tree.
The HardwareKeyboardDetector component allows you to directly listen
to events from a hardware keyboard, bypassing the Focus widget in Flutter.
It will not listen for events from any on-screen (software) keyboards.
A component that dispatches long-press gesture events to components
that use the LongPressCallbacks mixin. It will be attached to the
FlameGame instance automatically whenever any LongPressCallbacks
components are mounted into the component tree.
The event propagated through the Flame engine when the user completes
a long press gesture (i.e. the pointer has been held down long enough
to be recognized as a long press).
Dispatches both drag and scale events to DragCallbacks and
ScaleCallbacks components. Attached to the FlameGame automatically
when either callback type is first mounted.
NonPrimaryTapDispatcher propagates non-primary tap events (i.e.
secondary/right and tertiary/middle mouse clicks) to every component in the
component tree that is mixed with SecondaryTapCallbacks or
TertiaryTapCallbacks. This will be attached to the FlameGame instance
automatically whenever any of those callbacks are mounted into the
component tree.
MouseMoveDispatcher facilitates dispatching of mouse move events to the
PointerMoveCallbacks components in the component tree. It will be attached
to the FlameGame instance automatically whenever any
PointerMoveCallbacks components are mounted into the component tree.
ScrollDispatcher facilitates dispatching of pointer scroll events to the
ScrollCallbacks components in the component tree. It will be attached
to the FlameGame instance automatically whenever any
ScrollCallbacks components are mounted into the component tree.