handleTap method
A tap has occurred.
Flame reports taps through handleTapUp instead, which fires at the same
point in the gesture, so this is deliberately a no-op.
Implementation
void handleTap(int pointerId) {}
A tap has occurred.
Flame reports taps through handleTapUp instead, which fires at the same
point in the gesture, so this is deliberately a no-op.
void handleTap(int pointerId) {}