Marker interface implemented by every input callbacks mixin whose events carry a position (taps, drags, scrolls, hover) and thus participate in hit-testing.
Non-positional input, such as keyboard, implements InputCallbacks.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited