EmitterShape class abstract
The area, relative to the emitter's position, in which new particles spawn.
Subclass this to spawn particles in custom patterns.
- Implementers
Constructors
- EmitterShape()
-
Allows subclasses to have const constructors.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
samplePosition(
Random random, Vector2 out) → void -
Writes a spawn offset, relative to the emitter, into
out. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited