ParticleRange typedef
An inclusive range of doubles from which per-particle values are sampled.
Emitter properties that vary from particle to particle (lifespan, speed,
size, spin, etc.) are expressed as a (min, max) record. Use the same
value twice to get a constant, for example (5, 5).
Implementation
typedef ParticleRange = (double min, double max);