PointEmitterShape class
Spawns every particle exactly at the emitter's position.
- Inheritance
-
- Object
- EmitterShape
- PointEmitterShape
Constructors
- PointEmitterShape()
-
Spawns every particle exactly at the emitter's position.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
samplePosition(
Random random, Vector2 out) → void -
Writes a spawn offset, relative to the emitter, into
out.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited