leadingRunWidth property
double
get
leadingRunWidth
The width of the remaining content up to its first whitespace (all of it if hasBreakOpportunity is false), which is glued to any content that precedes it without whitespace.
Implementation
double get leadingRunWidth;